==> bones_api-1.3.41.tar.gz: test/bones_api_test_modules.dart <==
import 'package:bones_api/bones_api.dart';
import 'package:collection/collection.dart';

import 'bones_api_test_entities.dart';

part 'bones_api_test_modules.reflection.g.dart';

class TestAPIRoot extends APIRoot {
  TestAPIRoot() : super('Test', '1.0');

  @override
  Set<APIModule> loadModules() => {AboutModule(this), UserModule(this)};
}

@EnableReflection()
class AboutModule extends APIModule {
  AboutModule(APIRoot apiRoot) : super(apiRoot, 'about');

  @override
  void configure() {
    routes.anyFrom(reflection);
  }

  APIResponse<String> about() => APIResponse.ok('About...');
}

@APIEntityResolutionRules(EntityResolutionRules.fetchEager([User]))
@EnableReflection()
class UserModule extends APIModule {
  UserModule(APIRoot apiRoot) : super(apiRoot, 'user');

  @override
  void configure() {
    routes.anyFrom(reflection);
  }

  String notARoute(int n) => 'foo';

  Future<String> notARouteAsync(int n) async => 'foo';

  APIResponse<User> getUser(int id) => APIResponse.ok(User(
      'joe@email.com', 'pass123', Address('SC', 'NY', '', 123), [],
      creationTime: DateTime.utc(2021, 10, 11, 12, 13, 14)));

  APIResponse<User> echoUser(User user) =>
      APIResponse.ok(user..email += '.echo');

  APIResponse<List<User>> echoListUser(List<User> users) => APIResponse.ok(
      users.mapIndexed((i, e) => e..email += '.echo[$i]').toList());

  APIResponse<List<User>> echoListUser2(String msg, List<User> users) =>
      APIResponse.ok(
          users.mapIndexed((i, e) => e..email += '.echo[$i]{$msg}').toList());

  APIResponse getDynamic(int id) => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse<User>> getUserAsync(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse> geDynamicAsync(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<dynamic> geDynamicAsync2(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse<Map>> getContext() async {
    var cotextProvider = EntityRulesResolver.cotextProviders.first;

    var resolutionRules = cotextProvider.getContextEntityResolutionRules();

    return APIResponse.ok({'context': resolutionRules?.toJson()});
  }
}

==> bones_api-1.3.64.tar.gz: test/bones_api_test_modules.dart <==
import 'package:bones_api/bones_api.dart';
import 'package:collection/collection.dart';

import 'bones_api_test_entities.dart';

part 'bones_api_test_modules.reflection.g.dart';

class TestAPIRoot extends APIRoot {
  TestAPIRoot() : super('Test', '1.0');

  @override
  Set<APIModule> loadModules() => {AboutModule(this), UserModule(this)};
}

@EnableReflection()
class AboutModule extends APIModule {
  AboutModule(APIRoot apiRoot) : super(apiRoot, 'about');

  @override
  void configure() {
    routes.anyFrom(reflection);
  }

  APIResponse<String> about() => APIResponse.ok('About...');
}

bool _blockUserEmailCondition(EntityAccessRulesContext? c) =>
    c?.objectAs<User>()?.email.contains('secret') ?? false;

@APIEntityAccessRules(EntityAccessRules.blockFields(User, ['email'],
    condition: _blockUserEmailCondition))
@APIEntityResolutionRules(EntityResolutionRules.fetchEager([User]))
@EnableReflection()
class UserModule extends APIModule {
  UserModule(APIRoot apiRoot) : super(apiRoot, 'user');

  @override
  void configure() {
    routes.anyFrom(reflection);
  }

  String notARoute(int n) => 'foo';

  Future<String> notARouteAsync(int n) async => 'foo';

  APIResponse<User> getUser(int id) => APIResponse.ok(User(
      'joe@email.com', 'pass123', Address('SC', 'NY', '', 123), [],
      creationTime: DateTime.utc(2021, 10, 11, 12, 13, 14)));

  APIResponse<User> echoUser(User user) =>
      APIResponse.ok(user..email += '.echo');

  APIResponse<List<User>> echoListUser(List<User> users) => APIResponse.ok(
      users.mapIndexed((i, e) => e..email += '.echo[$i]').toList());

  APIResponse<List<User>> echoListUser2(String msg, List<User> users) =>
      APIResponse.ok(
          users.mapIndexed((i, e) => e..email += '.echo[$i]{$msg}').toList());

  APIResponse getDynamic(int id) => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse<User>> getUserAsync(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse> geDynamicAsync(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<dynamic> geDynamicAsync2(int id) async => APIResponse.ok(
      User('joe@email.com', 'pass123', Address('SC', 'NY', '', 123), []));

  Future<APIResponse<Map>> getContextEntityResolutionRules() async {
    var cotextProvider = EntityRulesResolver.cotextProviders.first;
    var resolutionRules = cotextProvider.getContextEntityResolutionRules();
    return APIResponse.ok(
        {'context.resolutionRules': resolutionRules?.toJson()});
  }

  Future<APIResponse<Map>> getRequestEntityResolutionRules(
      APIRequest request) async {
    var routeHandler = request.routeHandler;
    var resolutionRules = routeHandler?.entityResolutionRules;
    return APIResponse.ok({'resolutionRules': resolutionRules?.toJson()});
  }

  Future<APIResponse<Map>> getRequestEntityAccessRules(
      APIRequest request) async {
    var routeHandler = request.routeHandler;
    var accessRules = routeHandler?.entityAccessRules;
    return APIResponse.ok({'accessRules': accessRules?.toJson()});
  }
}
